# LALANG

A language transpiler for lazy polyglot programmers.

# Current status is still buggy (or rather, incomplete)

Some updates have not been applied to current version due to not enough free time.

# Usage

`language_specifier/lalang_code`

For example:
`py/the-code-goes-here`

# Examples

## Variable declaration

Create a variable `name` with value `Sarah`
`go/$name='Sarah'`

Output: `var name = "Sarah"`

Same as above, with type annotation:
Output: `var name string = "Sarah"`

Similarly for Typescript: 
`ts/$name='Sarah'`

the output will be: 
`let name: string = "Sarah";`

## Constant declaration

## Control flow

## Function

## Class

...(more to come)
